####################################################################################### 
    # This script consist of the estimation for the corrected expectation variable
    # For the sample 1990-04-01 to 2004-01-01, change the sample restriction.
    # The following code is based on teaching material at BI during the master's degree.
    # For this estimation, use the file: "Dataset_Reestimation of the expectation variable Jacobsen & Naug (2004)"
#######################################################################################

# Housekeeping
rm(list=ls())

# package needed to lastly extract the expectation variable 
#install.packages("writexl")

## Load packages
library(rmarkdown)  # to generate pdf file
library(tinytex)    # to generate pdf file
library(readxl)     # to read Excel files
library(lmtest)     # to generate tests
library(writexl)    # to extract the constructed variable 

#######################################################################################

## Set working directory  
setwd("/Users/piaegeberg/Desktop/Koding")

# Import data
data <- read_excel("/Users/piaegeberg/Desktop/Koding/Dataset_Reestimation of the expectation variable Jacobsen & Naug (2004).xls")
data       <- as.data.frame(data)

# Fixing the colmns
colnames(data) <- c("month", "hstock", "hprice", "hprice_s.adj", "wage", "disp.inc", "KPI", 
                    "KPI-JAE", "unem","interest.pre.tax" ,"taxrate", "TNSG", "S1", "S2", "S3", "interest.af.tax")
# Data as month
data$month <- as.Date(data$month)
data$TNSG <- as.numeric(data$TNSG)

#Measured as a rate 
data$TNSG <- data$TNSG/100 

################################################################################
################### Making new variables #######################################
################################################################################

## Finding the first difference ##
data$TNSG_diff      <- c(NA,       diff(data$TNSG))
data$interest.af.tax_diff      <- c(NA,       diff(data$interest.af.tax))
data$unem_diff  <- c(NA, diff(log(data$unem)))

# Finding the lags
data$TNSG_lag1 <- c(0, head(data$TNSG, -1))
data$interest.af.tax_lag1 <- c(0, head(data$interest.af.tax, -1))
data$unem_lag1 <- c(0, head(log(data$unem), -1))

## Restrict sample period to remove NA
data <- data[ (data$month >= "1992-10-01")  &  (data$month <= "2022-10-01"), ]


################################################################################
############################### Estimating EXPEC ############################### 
################################################################################

regr <- lm( TNSG_diff ~ interest.af.tax_diff + unem_diff + TNSG_lag1 
               + interest.af.tax_lag1 + unem_lag1 + S1 + S2 + S3, data=data)
summary(regr)

T <- nrow(regr$model)

### obtaining the residual ###
data$EXPEC <- summary(regr)$residual

################################################################################

# Extracting the variable EXPEC2 to a new Excel-sheet. 
write_xlsx(data.frame(EXPEC = data$EXPEC), "EXPEC2.xlsx")

### NOTE: 
### The extracted estimation results we obtained for both EXPEC and EXPEC2 are to be found in the Excel sheet called Dataset_Reestimation of Jacobsen & Naug (2004)
